@@ -4,6 +4,7 @@
 
 import requests
 import logging
+from resilient import is_env_proxies_set, get_and_parse_proxy_env_var, constants as res_constants
 from resilient_lib.components.integration_errors import IntegrationError
 from resilient_lib.util.lib_common import deprecated
 
@@ -33,6 +34,18 @@ class RequestsCommon:
     def get_proxies(self):
         """ proxies can be specified globally for all integrations or specifically per function """
         proxies = None
+
+        if is_env_proxies_set():
+            proxy_details = get_and_parse_proxy_env_var(res_constants.ENV_HTTPS_PROXY)
+
+            if not proxy_details:
+                proxy_details = get_and_parse_proxy_env_var(res_constants.ENV_HTTP_PROXY)
+
+            if proxy_details:
+                log.debug(u"Sending request through proxy: '{0}://{1}:{2}'".format(proxy_details.get("scheme"), proxy_details.get("hostname"), proxy_details.get("port")))
+
+            return proxies
+
         if self.integration_options and (self.integration_options.get("http_proxy") or self.integration_options.get("https_proxy")):
             proxies = {'http': self.integration_options.get("http_proxy"), 'https': self.integration_options.get("https_proxy")}
 
@@ -137,6 +150,9 @@ class RequestsCommon:
             log and log.error(msg)
             raise IntegrationError(msg)
 
+    # Create alias for execute_call_v2
+    execute = execute_call_v2
+
     @deprecated("Use the new method execute_call_v2()")
     def execute_call(self, verb, url, payload={}, log=None, basicauth=None, verify_flag=True, headers=None,
                      proxies=None, timeout=None, resp_type='json', callback=None):
