@@ -2,6 +2,7 @@ import json
 import logging
 import unittest
 import requests
+import os
 from parameterized import parameterized
 from resilient_lib import RequestsCommon, IntegrationError
 from resilient_lib.components.requests_common import get_case_insensitive_key_value, is_payload_in_json
@@ -47,7 +48,13 @@ class TestFunctionRequests(unittest.TestCase):
         self.assertEqual("abc", proxies['https'])
         self.assertEqual("def", proxies['http'])
 
-        
+        os.environ["HTTP_PROXY"] = "https://mock.example.com:3128"
+        integrations = { "integrations": { "https_proxy": "abc", 'http_proxy': 'def' } }
+        rc = RequestsCommon(integrations)
+        proxies = rc.get_proxies()
+        os.environ["HTTP_PROXY"] = ""
+        self.assertEqual(None, proxies)
+
     def test_timeout_overrides(self):
         # test default timeout
         integrations = { "integrations": { } }
@@ -200,7 +207,7 @@ class TestFunctionRequests(unittest.TestCase):
 
         # P O S T
         # test json argument without headers
-        resp = rc.execute_call_v2("post", "/".join((URL, "post")), json=payload)
+        resp = rc.execute("post", "/".join((URL, "post")), json=payload)
         print (resp.json())
         self.assertEqual(resp.json()["json"].get("body"), "bar")
 
@@ -213,7 +220,7 @@ class TestFunctionRequests(unittest.TestCase):
         headers_data = {
             "Content-type": "application/x-www-form-urlencoded"
         }
-        resp = rc.execute_call_v2("post", "/".join((URL, "post")), data=payload, headers=headers_data)
+        resp = rc.execute("post", "/".join((URL, "post")), data=payload, headers=headers_data)
         print (resp.json())
         self.assertEqual(resp.json()['json'].get("body"), "bar")
 
@@ -224,7 +231,7 @@ class TestFunctionRequests(unittest.TestCase):
 
         # P U T
         # With params
-        resp = rc.execute_call_v2("put", "/".join((URL, "put")), params=payload, headers=headers)
+        resp = rc.execute("put", "/".join((URL, "put")), params=payload, headers=headers)
         TestFunctionRequests.LOG.info(resp)
         self.assertTrue(resp.json()['args'].get("title"))
         self.assertEqual(resp.json()['args'].get("title"), 'foo')
